Skip to contents

Takes a matrix of covariates and generates a new matrix that contains the original covariates, all one-way interaction terms, and all squared terms.

Usage

matrixmaker(mat)

Arguments

mat

n by k numeric matrix of covariates.

Value

matrix with additional columns