Collect Covariate Balance Statistics
baltest.collect.RdA function that summarizes the covariate balance statistics that are computed by MatchBalance(Matching) in a balance table.
Arguments
- var.names
A vector of covariate names
- after
A logical flag for whether the results from before or after Matching should be summarized. If TRUE baltest.collect summarizes the results from the covariate balance checks that MatchBalance computes in the matched data. If FALSE the results from the balance checks in the unmatched data are used.
- matchbal
An object from a call to MatchBalance(Matching)