Generate Matrix of One-way Interactions and Squared Terms
matrixmaker.RdTakes a matrix of covariates and generates a new matrix that contains the original covariates, all one-way interaction terms, and all squared terms.
matrixmaker.RdTakes a matrix of covariates and generates a new matrix that contains the original covariates, all one-way interaction terms, and all squared terms.